@@ -4,7 +4,7 @@
 
 class FlexTypes
 {
-    typedef char Alphabet;
+    using Alphabet = char;
 
     public:
         static size_t const NCHARS =   1 << (8 * sizeof(Alphabet));
