@@ -6,7 +6,7 @@ void Generator::lop1(ostream &out) const
 "void " << d_baseclassScope << R"(lop1_(int lopSC)
 {
     d_lopMatched = d_matched;
-    d_lopPending = d_input.nPending();
+    d_lopPending = d_input->nPending();
 
     d_lopEnd = d_lopMatched.end();
     d_lopTail = d_lopEnd - 1;
