@@ -23,7 +23,7 @@ R"(
     d_get = &)" << d_baseclassScope << 
                             R"(getInput;          // restore get function
 
-    d_input.setPending(d_lopPending);
+    d_input->setPending(d_lopPending);
                                             // reinsert the tail into the 
                                             // input stream
     push(d_lopMatched.substr(length(), std::string::npos));
