@@ -9,7 +9,7 @@
     // is known it can be processed. This happens in assignBlock and in
     // noActions.
 
-void Parser::addRule(Pattern const &pattern, bool reset)
+void Parser::addRule(FPattern const &pattern, bool reset)
 {
     if (not d_scanner.allowNullMatches() && pattern.canBeEmpty(d_states))
     {
