@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-Pattern Parser::dollar()
+FPattern Parser::dollar()
 {
     if (not d_warnDollars)
         wmsg << "`$' inside regex loses its special meaning" << endl;
