@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-Pattern Parser::eolnDollar()
+FPattern Parser::eolnDollar()
 {
     d_scanner.eolnDollar();
     return rawText("");
