@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-Pattern Parser::lookahead(Pattern const &left, Pattern const &right)
+FPattern Parser::lookahead(FPattern const &left, FPattern const &right)
 {
     Options::regexCall("lookahead");
 
@@ -22,7 +22,7 @@ Pattern Parser::lookahead(Pattern const &left, Pattern const &right)
     d_doError = true;
     d_usesLOP = true;
 
-    Pattern ret;
+    FPattern ret;
     if (right.canBeEmpty(d_states))
     {
         wmsg << "null-matching trailing context is ignored" << endl;
@@ -31,12 +31,12 @@ Pattern Parser::lookahead(Pattern const &left, Pattern const &right)
     else if (right.fixedLength())            // fixed tail lop rule
     {
         d_rules.setFixedTailLOPrules();
-        ret = Pattern(d_states, right.length(), left, right);
+        ret = FPattern(d_states, right.length(), left, right);
     }
     else
     {
         d_rules.setVariableTailLOPrules();
-        ret = Pattern(d_states, left, right,  d_nLOPstartConditions);
+        ret = FPattern(d_states, left, right,  d_nLOPstartConditions);
         d_nLOPstartConditions += 2;
         d_scanner.needCatchAll();
     }
