@@ -2,6 +2,5 @@
 
 Ranges::~Ranges()
 {
-    delete[] d_ranges;
-    delete[] d_used;
+    delete[] d_alphabet;
 }
