@@ -9,7 +9,7 @@ size_t Rules::handleLopRule(size_t idx)
 
     Block action(rule->block());        // save the LOP rule's action block
 
-    Pattern const *pattern = &rule->pattern();
+    FPattern const *pattern = &rule->pattern();
 
     size_t scIndex = pattern->scIndex();
 
@@ -29,7 +29,7 @@ size_t Rules::handleLopRule(size_t idx)
                                         // activate the LOP rule's 1st SCs:
     d_startConditions.activate(scIndex);
                                         // and add this rule to that SC
-    add(false, Pattern(pattern->rhsPair()), workBlock, RuleType::LOP_2);
+    add(false, FPattern(pattern->rhsPair()), workBlock, RuleType::LOP_2);
 
 
     pattern = &d_rules[idx].pattern();  // reassign the pointer to the current
