@@ -6,5 +6,5 @@ int Scanner::handleMulti(int token)
         return token;
 
     accept(1);
-    return Parser::CHAR;
+    return Tokens::CHAR;
 }
