@@ -5,6 +5,6 @@ bool Scanner::handleStdComment()
     if (d_inCharClass)
         return true;
 
-    push(StartCondition__::comment);        
+    push(StartCondition_::comment);        
     return false;
 }
