@@ -1,6 +1,9 @@
+//#define XERR
 #include "state.ih"
 
 State::State(size_t type, string const &str, size_t next1, size_t next2)
 :
     State(type, new StateString(str, next1, next2))
-{}
+{
+    xerr((size_t)this % 1000 << ": d_data initialization by delegation");
+}
